@@ -14,8 +14,10 @@ def window(width:int, height:int):
 	pygame.init()
 	SCREEN_WIDTH = width 
 	SCREEN_HEIGHT = height
+
 	global win
 	win = pygame.display.set_mode((SCREEN_WIDTH, SCREEN_HEIGHT))
+	pygame.display.set_caption('GraphicswithPython')
 
 def putpixel(xcordinates:int, ycordinates:int, color:str, intensity:Optional[int] = None):
 	if intensity != None:
@@ -248,7 +250,7 @@ def midpointcircle(radius:int, xcenter:int, ycenter:int, midpointtype:str, color
 				putpixel( xcenter-y, ycenter-x, color)
 
 		if selectedType == 5:
-			dottedandline(xcenter, ycenter,x,y)
+			dottedandline(xcenter, ycenter,x,y, color)
 
 		
 		if(p < 0):
@@ -360,7 +362,7 @@ def boundaryfill(xcenter:int, ycenter:int, bordercolor:tuple, newcolor:tuple, se
 		else: 
 			return "plz enter seed as 4 or 8"
 
-def dottedandline(xcenter, ycenter, x, y):
+def dottedandline(xcenter:int, ycenter:int, x:int, y:int, colors:str):
 	for i in range(0, x):
 		if i%2 == 1:
 			putpixel( xcenter+x, ycenter+y, color("black"))
@@ -369,13 +371,13 @@ def dottedandline(xcenter, ycenter, x, y):
 			putpixel( xcenter-x, ycenter-y, color("black"))
 
 		else:
-			putpixel( xcenter+x, ycenter+y, color("white"))
-			putpixel( xcenter+y, ycenter+x, color("white"))
-			putpixel( xcenter-y, ycenter-x, color("white"))
-			putpixel( xcenter-x, ycenter-y, color("white"))
+			putpixel( xcenter+x, ycenter+y, colors)
+			putpixel( xcenter+y, ycenter+x, colors)
+			putpixel( xcenter-y, ycenter-x, colors)
+			putpixel( xcenter-x, ycenter-y, colors)
 
-		putpixel( xcenter+x, ycenter-y, color("white"))
-		putpixel( xcenter-x, ycenter+y, color("white"))
-		putpixel( xcenter+y, ycenter-x, color("white"))
-		putpixel( xcenter-y, ycenter+x, color("white"))
+		putpixel( xcenter+x, ycenter-y, colors)
+		putpixel( xcenter-x, ycenter+y, colors)
+		putpixel( xcenter+y, ycenter-x, colors)
+		putpixel( xcenter-y, ycenter+x, colors)
 
